@@ -1,16 +1,15 @@
 #![no_std]
 
 cfg_if::cfg_if! {
-    if #[cfg(any(feature = "custom", not(feature = "std")))] {
+    if #[cfg(feature = "custom")] {
         mod custom;
         use custom::CLOCK;
     } else {
-        mod std;
-        use std::CLOCK;
+        use time_clock::clock as CLOCK;
     }
 }
 
-static CLOCK_SOURCE: fn() -> u64 = CLOCK;
+pub static CLOCK_SOURCE: fn() -> u64 = CLOCK;
 
 /// Nanosecond since `app start time` or `os start time`
 pub fn now() -> u64 {
